@@ -1,6 +1,7 @@
 /*
  * This file is part of the Nepomuk KDE project.
  * Copyright (C) 2006-2010 Sebastian Trueg <trueg@kde.org>
+ * Copyright (C) 2012 Vishesh Handa <me@vhanda.in>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -39,6 +40,7 @@
 
 #include <Soprano/Vocabulary/NAO>
 #include <Soprano/Vocabulary/RDFS>
+#include <Soprano/Vocabulary/RDF>
 #include <Soprano/Model>
 #include <Soprano/QueryResultIterator>
 #include <Soprano/StatementIterator>
@@ -127,7 +129,7 @@ Nepomuk2::Resource& Nepomuk2::Resource::operator=( const QUrl& res )
 }
 
 
-QUrl Nepomuk2::Resource::resourceUri() const
+QUrl Nepomuk2::Resource::uri() const
 {
     if ( m_data ) {
         determineFinalResourceData();
@@ -139,7 +141,7 @@ QUrl Nepomuk2::Resource::resourceUri() const
 }
 
 
-QUrl Nepomuk2::Resource::resourceType() const
+QUrl Nepomuk2::Resource::type() const
 {
     determineFinalResourceData();
     return m_data->type();
@@ -149,29 +151,28 @@ QUrl Nepomuk2::Resource::resourceType() const
 QList<QUrl> Nepomuk2::Resource::types() const
 {
     determineFinalResourceData();
-    return m_data->allTypes();
+    return m_data->property( RDF::type() ).toUrlList();
 }
 
 
 void Nepomuk2::Resource::setTypes( const QList<QUrl>& types )
 {
     determineFinalResourceData();
-    m_data->setTypes( types );
+    m_data->setProperty( RDF::type(), types );
 }
 
 
 void Nepomuk2::Resource::addType( const QUrl& type )
 {
-    QList<QUrl> tl = types();
-    if( !tl.contains( type ) )
-        setTypes( tl << type );
+    determineFinalResourceData();
+    m_data->addProperty( RDF::type(), type );
 }
 
 
 bool Nepomuk2::Resource::hasType( const QUrl& typeUri ) const
 {
     determineFinalResourceData();
-    return m_data->hasType( typeUri );
+    return m_data->hasProperty( RDF::type(), typeUri );
 }
 
 
@@ -301,7 +302,7 @@ QString Nepomuk2::Resource::genericLabel() const
     QList<Resource> go = property( Vocabulary::PIMO::groundingOccurrence() ).toResourceList();
     if( !go.isEmpty() ) {
         label = go.first().genericLabel();
-        if( label != KUrl(go.first().resourceUri()).pathOrUrl() ) {
+        if( label != KUrl(go.first().uri()).pathOrUrl() ) {
             return label;
         }
     }
@@ -311,7 +312,7 @@ QString Nepomuk2::Resource::genericLabel() const
         return hashValue;
 
     // ugly fallback
-    return KUrl(resourceUri()).pathOrUrl();
+    return KUrl(uri()).pathOrUrl();
 }
 
 
@@ -376,7 +377,7 @@ bool Nepomuk2::Resource::operator==( const Resource& other ) const
     if( m_data->uri().isEmpty() )
         return *m_data == *other.m_data;
     else
-        return resourceUri() == other.resourceUri();
+        return uri() == other.uri();
 }
 
 
@@ -529,7 +530,7 @@ void Nepomuk2::Resource::setRating( const quint32& value )
 QList<Nepomuk2::Resource> Nepomuk2::Resource::isRelatedOf() const
 {
     Soprano::Model* model = ResourceManager::instance()->mainModel();
-    QList<Soprano::Node> list = model->listStatements( Soprano::Node(), NAO::isRelated(), resourceUri() ).iterateSubjects().allNodes();
+    QList<Soprano::Node> list = model->listStatements( Soprano::Node(), NAO::isRelated(), uri() ).iterateSubjects().allNodes();
     QList<Nepomuk2::Resource> resources;
     foreach(const Soprano::Node& node, list)
         resources << node.uri();
@@ -614,5 +615,5 @@ void Nepomuk2::Resource::determineFinalResourceData() const
 
 uint Nepomuk2::qHash( const Resource& res )
 {
-    return qHash(res.resourceUri());
+    return qHash(res.uri());
 }
